@@ -120,8 +120,7 @@ extract_lsm.RasterStack <- function(landscape,
 
     if (progress) {
 
-      message("\r> Progress nlayers: ", x , "/", length(landscape),
-              appendLF = FALSE)
+      cat("\r> Progress nlayers: ", x , "/", length(landscape))
     }
 
     extract_lsm_internal(landscape = landscape[[x]],
@@ -144,7 +143,7 @@ extract_lsm.RasterStack <- function(landscape,
 
   result$layer <- layer
 
-  if (progress) {message("")}
+  if (progress) {cat("\n")}
 
   result[with(result, order(layer, extract_id, level, metric, class, id)), ]
 }
@@ -169,8 +168,7 @@ extract_lsm.RasterBrick <- function(landscape,
 
     if (progress) {
 
-      message("\r> Progress nlayers: ", x , "/", length(landscape),
-              appendLF = FALSE)
+      cat("\r> Progress nlayers: ", x , "/", length(landscape))
     }
 
     extract_lsm_internal(landscape = landscape[[x]],
@@ -193,7 +191,7 @@ extract_lsm.RasterBrick <- function(landscape,
 
   result$layer <- layer
 
-  if (progress) {message("")}
+  if (progress) {cat("\n")}
 
   result[with(result, order(layer, extract_id, level, metric, class, id)), ]
 }
@@ -220,8 +218,7 @@ extract_lsm.stars <- function(landscape,
 
     if (progress) {
 
-      message("\r> Progress nlayers: ", x , "/", length(landscape),
-              appendLF = FALSE)
+      cat("\r> Progress nlayers: ", x , "/", length(landscape))
     }
 
     extract_lsm_internal(landscape = landscape[[x]],
@@ -244,7 +241,7 @@ extract_lsm.stars <- function(landscape,
 
   result$layer <- layer
 
-  if (progress) {message("")}
+  if (progress) {cat("\n")}
 
   result[with(result, order(layer, extract_id, level, metric, class, id)), ]
 }
@@ -267,8 +264,7 @@ extract_lsm.list <- function(landscape,
 
     if (progress) {
 
-      message("\r> Progress nlayers: ", x , "/", length(landscape),
-              appendLF = FALSE)
+      cat("\r> Progress nlayers: ", x , "/", length(landscape))
     }
 
     extract_lsm_internal(landscape = landscape[[x]],
@@ -291,7 +287,7 @@ extract_lsm.list <- function(landscape,
 
   result$layer <- layer
 
-  if (progress) {message("")}
+  if (progress) {cat("\n")}
 
   result[with(result, order(layer, extract_id, level, metric, class, id)), ]
 }
@@ -321,15 +317,15 @@ extract_lsm_internal <- function(landscape,
   }
 
   # check if sf object is provided
-  if (methods::is(y, "sf")) {
+  if (inherits(x = y, what = "sf")) {
 
     # check if points have the right class
-    if (any(class(y) %in% c("MULTIPOINT", "POINT"))) {
+    if (inherits(x = y, what = c("MULTIPOINT", "POINT"))) {
 
       y <- matrix(sf::st_coordinates(y)[, 1:2], ncol = 2)
     }
 
-    else if (any(class(y) %in% c("sf", "sfc"))) {
+    else if (inherits(x = y, what = c("sf", "sfc"))) {
 
       if (all(sf::st_geometry_type(y) %in% c("POINT", "MULTIPOINT"))) {
 
@@ -344,7 +340,8 @@ extract_lsm_internal <- function(landscape,
       }
     }
 
-    else if (any(class(y) %in% c("LINESTRING", "POLYGON", "MULTILINESTRING", "MULTIPOLYGON"))) {
+    else if (inherits(x = y, what = c("LINESTRING", "POLYGON",
+                                      "MULTILINESTRING", "MULTIPOLYGON"))) {
 
       stop(
         "landscapemetrics currently only supports sf point features for landscape metrics extraction."
@@ -353,12 +350,12 @@ extract_lsm_internal <- function(landscape,
   }
 
   # if Spatial Lines disaggregate
-  else if (methods::is(y, "SpatialLines") | methods::is(y, "SpatialLinesDataFrame")) {
+  else if (inherits(x = y, what = c("SpatialLines", "SpatialLinesDataFrame"))) {
 
     y <- sp::disaggregate(y)
   }
 
-  else if (!methods::is(y, "matrix") & !methods::is(y, "SpatialPoints") & !methods::is(y, "SpatialPointsDataFrame")) {
+  else if (!inherits(x = y, what = c("matrix", "SpatialPoints", "SpatialPointsDataFrame"))) {
 
     stop("'y' must be a matrix, SpatialPoints, SpatialLines or sf point geometries.",
          call. = FALSE)
