@@ -166,18 +166,28 @@ lsm_p_cai_calc <- function(landscape, directions, consider_boundary, edge_depth,
 
 
     # convert to matrix
-    if(class(landscape) != "matrix") {
+    if (!inherits(x = landscape, what = "matrix")) {
         resolution <- raster::res(landscape)
+
         landscape <- raster::as.matrix(landscape)
     }
 
+    # all values NA
+    if (all(is.na(landscape))) {
+        return(tibble::tibble(level = "patch",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "cai",
+                              value = as.double(NA)))
+    }
+
     # get patch area
     area_patch <- lsm_p_area_calc(landscape = landscape,
                                   directions = directions,
                                   resolution = resolution)
 
     # convert from ha to sqm
-    area_patch$value <- area_patch$value * 10000
+    area_patch$value <- area_patch$value
 
     # get core area
     core_patch <- lsm_p_core_calc(landscape,
@@ -187,7 +197,7 @@ lsm_p_cai_calc <- function(landscape, directions, consider_boundary, edge_depth,
                                   resolution = resolution)
 
     # calculate CAI index
-    cai_patch <- core_patch$value * 10000 / area_patch$value * 100
+    cai_patch <- core_patch$value / area_patch$value * 100
 
     tibble::tibble(
         level = "patch",
