@@ -49,6 +49,8 @@
 #' landscape structure using the GRASS geographical information system.
 #' Landscape Ecology 7: 291-302.
 #'
+#' Based on C++ code from Project Nayuki (https://www.nayuki.io/page/smallest-enclosing-circle).
+#'
 #' @export
 lsm_p_circle <- function(landscape, directions) UseMethod("lsm_p_circle")
 
@@ -134,15 +136,11 @@ lsm_p_circle.list <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_p_circle_calc <- function(landscape, directions,
-                              points = NULL, resolution = NULL) {
+lsm_p_circle_calc <- function(landscape, directions, resolution = NULL) {
 
     # conver to matrix
     if (!inherits(x = landscape, what = "matrix")) {
 
-        # get coordinates and values of all cells
-        points <- raster_to_points(landscape)[, 2:4]
-
         # get resolution
         resolution <- raster::res(landscape)
 
@@ -150,6 +148,13 @@ lsm_p_circle_calc <- function(landscape, directions,
         landscape <- raster::as.matrix(landscape)
     }
 
+    # check if resolution is identical
+    if (!isTRUE(all.equal(resolution[1], resolution[2]))) {
+
+        stop("The area of the circumscribing circle is currently only implemented for equal resolutions.",
+             call. = FALSE)
+    }
+
     # all values NA
     if (all(is.na(landscape))) {
         return(tibble::tibble(level = "patch",
@@ -159,17 +164,13 @@ lsm_p_circle_calc <- function(landscape, directions,
                               value = as.double(NA)))
     }
 
-    # get resolution of landscape
-    resolution_x <- resolution[[1]]
-    resolution_y <- resolution[[2]]
-
     # get patch area
     area_patch <- lsm_p_area_calc(landscape,
                                   directions = directions,
                                   resolution = resolution)
 
-    # patches with only 1 cell
-    one_cell <- which(area_patch$value == prod(resolution) / 10000)
+    # convert area to m2
+    area_patch <- area_patch$value * 10000
 
     # get unique classes
     classes <- get_unique_values(landscape)[[1]]
@@ -183,43 +184,17 @@ lsm_p_circle_calc <- function(landscape, directions,
                                          directions = directions,
                                          return_raster = FALSE)[[1]]
 
-        # only boundary cells need to be considered for circle diameter
-        class_boundaries <- get_boundaries(landscape_labeled,
-                                           directions = 4,
-                                           as_NA = TRUE,
-                                           consider_boundary = FALSE)[[1]]
-
-        # transpose matrix to have same order as in points
-        class_boundaries <- t(class_boundaries)
-        landscape_labeled <- t(landscape_labeled)
-
-        # get coordinates of current class
-        points <- matrix(points[which(!is.na(class_boundaries)), ],
-                         ncol = 3)
-
-        # use patch id instead of class id
-        points[, 3] <- landscape_labeled[!is.na(class_boundaries)]
-
         # get circle radius around patch
-        circle <- rcpp_get_circle(points,
-                                  resolution_x = resolution_x,
-                                  resolution_y = resolution_y)
-        # calculate circle area
-        circle[, 2] <- pi * ((circle[, 2] / 2) ^ 2)
-
-        # sort according to patch id
-        circle <- matrix(circle[order(circle[,1]),], ncol = 2)
+        circle <- rcpp_get_circle(landscape_labeled,
+                                  resolution_xy = resolution[[1]])
 
         tibble::tibble(class = patches_class,
-                       value = circle[,2])
+                       value = circle$circle_area)
         })
     )
 
     # calculate circle metric
-    circle_patch$value <- 1 - (area_patch$value * 10000) / circle_patch$value
-
-    # set all one-cell patches to 0
-    circle_patch$value[one_cell] <- 0
+    circle_patch$value <- 1 - (area_patch / circle_patch$value)
 
     tibble::tibble(
         level = "patch",
